@@ -1,6 +1,8 @@
-def generate_collection_firestore_name(collection_name, prefix=''):
+def generate_collection_firestore_name(collection_name, prefix='', full_collection_name=False):
     from stratus_api.core.settings import get_app_settings
     app_settings = get_app_settings()
+    if full_collection_name:
+        return collection_name
     return "{0}-{1}-{2}{3}".format(app_settings['service_name'], app_settings['environment'], prefix, collection_name)
 
 
@@ -27,3 +29,17 @@ def manage_retries(partial_function, handled_exceptions, propagate_exceptions, r
         else:
             success = True
     return results
+
+
+def delete_collection_documents(collection, full_collection_name=False):
+    from stratus_api.document import create_db_client
+    db = create_db_client()
+    chunk_size = 10
+    collection = generate_collection_firestore_name(collection_name=collection, full_collection_name=full_collection_name)
+    while chunk_size > 0:
+        chunk_size = 0
+        chunk = db.collection(collection).limit(100).get()
+        for document in chunk:
+            document.reference.delete()
+            chunk_size += 1
+    pass
\ No newline at end of file
